// Account model definition
import { Sequelize, DataTypes, Model, Optional, Attributes, CreateOptions, ModelStatic } from 'sequelize';
import { HookReturn } from 'sequelize/types/hooks';

import { Transaction } from './Transaction'; // Import the Transaction model

interface AccountAttributes {
    AccountID: number;
    Name: string;
    // Other account fields...
}

interface AccountCreationAttributes extends Optional<AccountAttributes, 'AccountID'> { }

class Account extends Model<AccountAttributes, AccountCreationAttributes> implements AccountAttributes {
    public AccountID!: number;
    public Name!: string;

    static initialize(sequelize: Sequelize): void {
        Account.init(
            {
                AccountID: {
                    type: DataTypes.INTEGER,
                    primaryKey: true,
                    autoIncrement: true,
                },
                Name: {
                    type: DataTypes.STRING,
                    allowNull: false,
                },
                // Other account fields...
            },
            {
                sequelize,
                modelName: 'Account',
                hooks: {
                    afterCreate: (attributes: Account, options: CreateOptions<AccountAttributes>) => {
                        console.log(attributes)
                    },
                    beforeCreate(attributes: Account, options: CreateOptions<AccountAttributes>) {
                        console.log(attributes)
                    },
                }
            }
        );
    }

    static associate(models: { Transaction: typeof Transaction }): void {
        Account.hasMany(models.Transaction, { foreignKey: 'AccountID' }); // An account can have multiple transactions
    }
}

export { Account };
