import { Sequelize, DataTypes, Model, Optional } from 'sequelize';
import { User } from './User';
import { Transaction } from './Transaction';

// Category attributes interface
interface CategoryAttributes {
    CategoryID: number;
    Name: string;
    Description: string | null;
    // Other fields...
  }
  
  // Category creation attributes (optional fields)
  interface CategoryCreationAttributes extends Optional<CategoryAttributes, 'CategoryID'> {}
  
  // Define the Category model
  class Category extends Model<CategoryAttributes, CategoryCreationAttributes> implements CategoryAttributes {
    public CategoryID!: number;
    public Name!: string;
    public Description!: string | null;
    // Other fields...
  
    static initialize(sequelize: Sequelize): void {
      Category.init(
        {
          CategoryID: {
            type: DataTypes.INTEGER,
            primaryKey: true,
            autoIncrement: true,
          },
          Name: {
            type: DataTypes.STRING,
            allowNull: false,
          },
          Description: {
            type: DataTypes.STRING,
            allowNull: true,
          },
          // Other fields...
        },
        {
          sequelize,
          modelName: 'Category',
          // Other model options...
        }
      );
    }
    static associate(models: { User: typeof User; Transaction: typeof Transaction }): void {
      Category.belongsToMany(models.Transaction,{through:"TransactionCategory"}); // A category can have multiple transactions
    }
  }
  

  export {Category };