import { Sequelize, DataTypes, Model, Optional } from 'sequelize';
import { Category } from './Category';
import { Transaction } from './Transaction';

// User attributes interface
interface UserAttributes {
    UserID: number;
    Name: string;
    Email: string;
    Password: string;
    // Other fields...
}

// User creation attributes (optional fields)
interface UserCreationAttributes extends Optional<UserAttributes, 'UserID'> { }

// Define the User model
class User extends Model<UserAttributes, UserCreationAttributes> implements UserAttributes {
    public UserID!: number;
    public Name!: string;
    public Email!: string;
    public Password!: string;

    // Other fields...

    static initialize(sequelize: Sequelize): void {
        User.init(
            {
                UserID: {
                    type: DataTypes.INTEGER,
                    primaryKey: true,
                    autoIncrement: true,
                },
                Name: {
                    type: DataTypes.STRING,
                    allowNull: false,
                },
                Email: {
                    type: DataTypes.STRING,
                    allowNull: false,
                    unique: true,
                },
                Password: {
                    type: DataTypes.STRING,
                    allowNull: false,
                },
                // Other fields...
            },
            {
                sequelize,
                modelName: 'User',
                // Other model options...
            }
        );
    }
    static associate(models: { Category: typeof Category; Transaction: typeof Transaction }): void {
        User.hasMany(models.Transaction, { foreignKey: 'UserID' });
    }
}


export { User };