import express, { Request, Response } from 'express';
import { Account, Category, Transaction } from "../models";
import moment from "moment";
import { convertDateArray } from '../helper/dateConversion';


import { addTransaction, addTransfer, listTransactions } from './transactions/index';
import { Op } from 'sequelize';

export class TransactionRouter {
    static routes() {
        let router = express.Router();
        router.use((req, res, next) => {
            console.log("TEST")
            next()
        })


        router.post('/addTransaction', addTransaction.POST)
        router.get('/addTransaction', addTransaction.GET)


        router.post('/addTransfer', addTransfer.POST)
        router.get('/addTransfer', addTransfer.GET)

        router.get('/modifyTransfer/:id', async (req, res,next ) => {
            try {
                await listTransactions.GET(req, res, next, {
                    where: {
                        AccountID: req.params.acc
                    }
                })
            } catch (err) {
                console.error(err);
                res.status(500).send('Internal Server Error');
            }

        })

        router.get('/acc/:acc/_/:year/:month',async(req,res,next)=>{
            try {
                let m = moment();
                m.set({
                    year: parseInt(req.params.year),
                    month: parseInt(req.params.month) - 1,
                    date: 1
                });
                await listTransactions.GET(req, res, next, {
                    date: m.toDate(),
                    where: {
                        AccountID: req.params.acc
                    }
                })
            } catch (err) {
                console.error(err);
                res.status(500).send('Internal Server Error');
            }
        })
        router.get('/acc/:acc', async (req: Request, res: Response,next) => {
            try {
                await listTransactions.GET(req, res, next, {
                    where: {
                        AccountID: req.params.acc
                    }
                })
            } catch (err) {
                console.error(err);
                res.status(500).send('Internal Server Error');
            }
        });
        router.get('/cat/:cat/_/:year/:month', async (req: Request, res: Response, next) => {
            try {
                let m = moment();
                m.set({
                    year: parseInt(req.params.year),
                    month: parseInt(req.params.month) - 1,
                    date: 1
                });
                await listTransactions.GET(req, res, next, {
                    date: m.toDate(),
                    where: {
                        CategoryID: req.params.cat
                    }
                })
            } catch (err) {
                console.error(err);
                res.status(500).send('Internal Server Error');
            }
        });
        router.get('/cat/:cat', async (req: Request, res: Response, next) => {
            try {
                await listTransactions.GET(req, res, next, {
                    where: {
                        CategoryID: req.params.cat
                    }
                })
            } catch (err) {
                console.error(err);
                res.status(500).send('Internal Server Error');
            }
        });
        router.get('/_/:year/:month', async (req, res, next) => {
            try {
                let m = moment();
                m.set({
                    year: parseInt(req.params.year),
                    month: parseInt(req.params.month) - 1,
                    date: 1
                });
                await listTransactions.GET(req, res, next, { date: m.toDate() })
            } catch (err) {
                console.error(err);
                res.status(500).send('Internal Server Error');
            }
        })
        router.get('/', listTransactions.GET)

        return router;
    }
}
