import { Request, NextFunction, Response } from "express";
import moment from "moment";
import { Op } from "sequelize";

import { Category, Transaction, Account } from "../../models";
import { convertDateArray } from "../../helper/dateConversion";
import { getFirstLastDayOfMonth } from "../../helper";

const GET = async (req: Request, res: Response, next: NextFunction, data:any = {date:new Date(),where:{}}) => {
    try {
        moment.locale("de")
        let m = moment(data.date);
        let { startDate, endDate } = getFirstLastDayOfMonth(m);
        let transactions:any = await Transaction.findAll({
            include: [Account,Category],
            where:{
                Date:{
                    [Op.between]:[startDate.toDate(),endDate.toDate()]
                },
                ...data.where
            }
        });
        const categories = await Category.findAll({});
        const accounts = await Account.findAll({});
        let arr = convertDateArray(transactions);
        
        res.render('transactions/listTransactions', { title: 'Transactions', transactions: arr, categories, accounts, cssClass:"fullList" });
    } catch (err) {
        console.error(err);
        res.status(500).send('Internal Server Error');
    }
}

export default { GET };