import { Sequelize, DataTypes, Model, Optional } from 'sequelize';
import { Account, Category, Transaction, User } from './controller/models';
import { Router } from './controller/router';

import path from 'path';
import { fileURLToPath } from 'url';
import { Storage } from './controller/storage';
import { MonthlyReport } from './controller/models/MonthlyReport';
import { testData } from './test-data';


Storage.__dirname = __dirname



let init = async () => {
    // Initialize Sequelize instance and define database connection
    /*const sequelize = new Sequelize('sqlite::memory:', {
        host: 'localhost',
        dialect: 'sqlite', // Change this to your database dialect
        // Other options...
    });
    */
    const sequelize = new Sequelize({
        dialect: 'sqlite',
        storage:`${path.join(__dirname,'../data')}/database.sqlite`
      });

    User.initialize(sequelize);

    Category.initialize(sequelize);

    Transaction.initialize(sequelize);


    Account.initialize(sequelize);

    MonthlyReport.initialize(sequelize);
    // Set up associations between models
    User.associate({ Transaction, Category });
    Category.associate({ User, Transaction });
    Transaction.associate({ User, Category, Account, MonthlyReport });
    Account.associate({Transaction})

    MonthlyReport.associate({ Transaction, Account });

    await sequelize.sync({ force: true });

    await testData(User,Category,Account,MonthlyReport)

    new Router(path.join(__dirname,'../public'));

    //console.log(path.join(__dirname,'../public'))

    //MonthlyReport.generateMonthlyReport(12,2023,2)
}

init();